@@ -162,7 +162,7 @@ public:
      */
     struct text
     {
-        explicit text (const char *text) : t(text) {}
+        explicit text (const char *content) : t(content) {}
         const char *t;
     };
 
@@ -428,8 +428,10 @@ public:
         The xml::node::iterator provides a way to access children nodes
         similar to a standard C++ container. The nodes that are pointed to by
         the iterator can be changed.
+
+        Note that this is only a forward iterator.
      */
-    class iterator
+    class XMLWRAPP_API iterator
     {
     public:
         typedef node value_type;
@@ -469,8 +471,10 @@ public:
         The xml::node::const_iterator provides a way to access children nodes
         similar to a standard C++ container. The nodes that are pointed to by
         the const_iterator cannot be changed.
+
+        Note that this is only a forward iterator.
      */
-    class const_iterator
+    class XMLWRAPP_API const_iterator
     {
     public:
         typedef const node value_type;
@@ -888,18 +892,14 @@ private:
 
 // Comparison operators for xml::node iterators
 
-inline bool XMLWRAPP_API operator==(const node::iterator& lhs,
-                                    const node::iterator& rhs)
+inline bool operator==(const node::iterator& lhs, const node::iterator& rhs)
     { return lhs.get_raw_node() == rhs.get_raw_node(); }
-inline bool XMLWRAPP_API operator!=(const node::iterator& lhs,
-                                    const node::iterator& rhs)
+inline bool operator!=(const node::iterator& lhs, const node::iterator& rhs)
     { return !(lhs == rhs); }
 
-inline bool XMLWRAPP_API operator==(const node::const_iterator& lhs,
-                                    const node::const_iterator& rhs)
+inline bool operator==(const node::const_iterator& lhs, const node::const_iterator& rhs)
     { return lhs.get_raw_node() == rhs.get_raw_node(); }
-inline bool XMLWRAPP_API operator!=(const node::const_iterator& lhs,
-                                    const node::const_iterator& rhs)
+inline bool operator!=(const node::const_iterator& lhs, const node::const_iterator& rhs)
     { return !(lhs == rhs); }
 
 } // namespace xml
