@@ -55,13 +55,6 @@ namespace xml
 
 using namespace xml::impl;
 
-// This is a hack to fix a problem with a change in the libxml2 API for
-// versions starting at 2.6.0
-#if LIBXML_VERSION >= 20600
-    #define initxmlDefaultSAXHandler xmlSAX2InitDefaultSAXHandler
-    #include <libxml/SAX2.h>
-#endif
-
 // ------------------------------------------------------------------------
 // xml::impl::epimpl
 // ------------------------------------------------------------------------
@@ -400,7 +393,7 @@ bool event_parser::parse_stream(std::istream& stream)
 
 bool xml::event_parser::parse_chunk(const char *chunk, size_type length)
 {
-    xmlParseChunk(pimpl_->parser_context_, chunk, length, 0);
+    xmlParseChunk(pimpl_->parser_context_, chunk, xml::impl::checked_int_cast(length), 0);
     return pimpl_->parser_status_;
 }
 
