@@ -40,7 +40,6 @@
 #include "utility.h"
 #include "ait_impl.h"
 #include "node_manip.h"
-#include "pimpl_base.h"
 #include "node_iterator.h"
 
 // standard includes
@@ -71,7 +70,7 @@ using namespace xml::impl;
 namespace impl
 {
 
-struct node_impl : public pimpl_base<xml::impl::node_impl>
+struct node_impl
 {
     node_impl() : xmlnode_(0), owner_(true), attrs_(0) {}
     ~node_impl() { release(); }
@@ -319,9 +318,11 @@ node::node (const char *name, const char *content)
 
 node::node(cdata cdata_info)
 {
+    const int len = xml::impl::checked_int_cast(std::strlen(cdata_info.t));
+
     xml::impl::auto_ptr<node_impl> ap(pimpl_ = new node_impl);
 
-    if ( (pimpl_->xmlnode_ = xmlNewCDataBlock(0, reinterpret_cast<const xmlChar*>(cdata_info.t), std::strlen(cdata_info.t))) == 0)
+    if ( (pimpl_->xmlnode_ = xmlNewCDataBlock(0, reinterpret_cast<const xmlChar*>(cdata_info.t), len)) == 0)
     {
         throw std::bad_alloc();
     }
@@ -515,9 +516,14 @@ const char* node::get_content() const
 
 node::node_type node::get_type() const
 {
+    // Note that XML_xxx values are listed here in order of their declaration
+    // in xmlElementType, for ease of comparison.
     switch (pimpl_->xmlnode_->type)
     {
         case XML_ELEMENT_NODE:          return type_element;
+        // List for completeness, but this is impossible here as attrubutes are
+        // represented by xml::attribute objects, not xml::node ones.
+        case XML_ATTRIBUTE_NODE:        break;
         case XML_TEXT_NODE:             return type_text;
         case XML_CDATA_SECTION_NODE:    return type_cdata;
         case XML_ENTITY_REF_NODE:       return type_entity_ref;
@@ -528,6 +534,9 @@ node::node_type node::get_type() const
         case XML_DOCUMENT_TYPE_NODE:    return type_document_type;
         case XML_DOCUMENT_FRAG_NODE:    return type_document_frag;
         case XML_NOTATION_NODE:         return type_notation;
+        // Another impossible case: we never call htmlNewDoc(), so we are never
+        // going to have objects of this type.
+        case XML_HTML_DOCUMENT_NODE:    break;
         case XML_DTD_NODE:              return type_dtd;
         case XML_ELEMENT_DECL:          return type_dtd_element;
         case XML_ATTRIBUTE_DECL:        return type_dtd_attribute;
@@ -535,8 +544,14 @@ node::node_type node::get_type() const
         case XML_NAMESPACE_DECL:        return type_dtd_namespace;
         case XML_XINCLUDE_START:        return type_xinclude;
         case XML_XINCLUDE_END:          return type_xinclude;
-        default:                        return type_element;
+        // This is also impossible as we don't use DocBook and, in addition,
+        // needs to be made conditional as this symbols is not always defined.
+#ifdef LIBXML_DOCB_ENABLED
+        case XML_DOCB_DOCUMENT_NODE:    break;
+#endif
     }
+
+    throw std::logic_error("unknown or unexpected node type");
 }
 
 
@@ -589,7 +604,7 @@ void node::set_namespace(const std::string& href)
         {
             if ( ns->prefix == NULL )
             {
-                xmlFree((void*)ns->href);
+                xmlFree(const_cast<xmlChar*>(ns->href));
                 ns->href = xmlStrdup(xmlHref);
                 break;
             }
@@ -617,7 +632,7 @@ void node::push_back (const node &child)
 node::size_type node::size() const
 {
     using namespace std;
-    return distance(begin(), end());
+    return checked_size_t_cast(distance(begin(), end()));
 }
 
 
@@ -863,7 +878,7 @@ std::string node::node_to_string() const
     xmlchar_helper helper(xml_string);
     std::string xml;
     if (xml_string_length)
-        xml.assign(helper.get(), xml_string_length);
+        xml.assign(helper.get(), checked_size_t_cast(xml_string_length));
     return xml;
 }
 
