@@ -36,13 +36,11 @@
 #include <functional>
 
 
-BOOST_AUTO_TEST_SUITE( node )
-
 /*
  * This test should make sure that we can construct a tree using nodes and
  * output the nodes using stream insertion.
  */
-BOOST_AUTO_TEST_CASE( create_node )
+TEST_CASE_METHOD( SrcdirConfig, "node/create_node", "[node]" )
 {
     xml::node root_node("root");
     xml::node one("count", "one");
@@ -55,7 +53,7 @@ BOOST_AUTO_TEST_CASE( create_node )
     root_node.push_back(two);
     root_node.push_back(nested_out);
 
-    BOOST_CHECK( is_same_as_file(root_node, "node/data/01.out") );
+    CHECK( is_same_as_file(root_node, "node/data/01.out") );
 }
 
 
@@ -63,15 +61,15 @@ BOOST_AUTO_TEST_CASE( create_node )
  * This test checks xml::node::iterator xml::node::find (const char *name);
  */
 
-BOOST_AUTO_TEST_CASE( find )
+TEST_CASE_METHOD( SrcdirConfig, "node/find", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     xml::node::iterator i = root.find("person");
 
-    BOOST_REQUIRE( i != root.end() );
-    BOOST_CHECK( is_same_as_file(*i, "node/data/02a.out") );
+    REQUIRE( i != root.end() );
+    CHECK( is_same_as_file(*i, "node/data/02a.out") );
 }
 
 
@@ -79,15 +77,15 @@ BOOST_AUTO_TEST_CASE( find )
  * This test checks xml::node::const_iterator xml::node::find (const char *name) const;
  */
 
-BOOST_AUTO_TEST_CASE( find_consts )
+TEST_CASE_METHOD( SrcdirConfig, "node/find_consts", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
 
     const xml::node& root = parser.get_document().get_root_node();
     xml::node::const_iterator i = root.find("person");
 
-    BOOST_REQUIRE( i != root.end() );
-    BOOST_CHECK( is_same_as_file(*i, "node/data/02a.out") );
+    REQUIRE( i != root.end() );
+    CHECK( is_same_as_file(*i, "node/data/02a.out") );
 }
 
 
@@ -95,7 +93,7 @@ BOOST_AUTO_TEST_CASE( find_consts )
  * This test checks xml::node::iterator xml::node::find (const char *name, * iterator start);
  */
 
-BOOST_AUTO_TEST_CASE( find_with_start )
+TEST_CASE_METHOD( SrcdirConfig, "node/find_with_start", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
 
@@ -110,7 +108,7 @@ BOOST_AUTO_TEST_CASE( find_with_start )
         i = root.find("person", ++i);
     }
 
-    BOOST_CHECK( is_same_as_file( ostr, "node/data/02c.out") );
+    CHECK( is_same_as_file( ostr, "node/data/02c.out") );
 }
 
 
@@ -118,7 +116,7 @@ BOOST_AUTO_TEST_CASE( find_with_start )
  * This test checks xml::node::const_iterator xml::node::find (const char *name, * iterator start) const;
  */
 
-BOOST_AUTO_TEST_CASE( find_with_start_const )
+TEST_CASE_METHOD( SrcdirConfig, "node/find_with_start_const", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
 
@@ -133,7 +131,7 @@ BOOST_AUTO_TEST_CASE( find_with_start_const )
         i = root.find("person", ++i);
     }
 
-    BOOST_CHECK( is_same_as_file( ostr, "node/data/02c.out") );
+    CHECK( is_same_as_file( ostr, "node/data/02c.out") );
 }
 
 
@@ -141,14 +139,14 @@ BOOST_AUTO_TEST_CASE( find_with_start_const )
  * This test checks xml::node::elements (const char *name);
  */
 
-BOOST_AUTO_TEST_CASE( elements )
+TEST_CASE_METHOD( SrcdirConfig, "node/elements", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     xml::nodes_view persons(root.elements("person"));
 
-    BOOST_CHECK_EQUAL( persons.size(), 3u );
+    CHECK( persons.size() == 3u );
 
     std::ostringstream ostr;
 
@@ -157,7 +155,7 @@ BOOST_AUTO_TEST_CASE( elements )
         ostr << *i;
     }
 
-    BOOST_CHECK( is_same_as_file( ostr, "node/data/02c.out") );
+    CHECK( is_same_as_file( ostr, "node/data/02c.out") );
 }
 
 
@@ -165,14 +163,14 @@ BOOST_AUTO_TEST_CASE( elements )
  * This test checks xml::node::elements (const char *name) const;
  */
 
-BOOST_AUTO_TEST_CASE( elements_const )
+TEST_CASE_METHOD( SrcdirConfig, "node/elements_const", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
 
     const xml::node &root = parser.get_document().get_root_node();
     xml::const_nodes_view persons(root.elements("person"));
 
-    BOOST_CHECK_EQUAL( persons.size(), 3u );
+    CHECK( persons.size() == 3u );
 
     std::ostringstream ostr;
 
@@ -181,7 +179,7 @@ BOOST_AUTO_TEST_CASE( elements_const )
         ostr << *i;
     }
 
-    BOOST_CHECK( is_same_as_file( ostr, "node/data/02c.out") );
+    CHECK( is_same_as_file( ostr, "node/data/02c.out") );
 }
 
 
@@ -189,7 +187,7 @@ BOOST_AUTO_TEST_CASE( elements_const )
  * This test checks xml::node::elements();
  */
 
-BOOST_AUTO_TEST_CASE( elements_all )
+TEST_CASE_METHOD( SrcdirConfig, "node/elements_all", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
 
@@ -203,7 +201,7 @@ BOOST_AUTO_TEST_CASE( elements_all )
         ostr << *i;
     }
 
-    BOOST_CHECK( is_same_as_file( ostr, "node/data/02g.out") );
+    CHECK( is_same_as_file( ostr, "node/data/02g.out") );
 }
 
 
@@ -211,7 +209,7 @@ BOOST_AUTO_TEST_CASE( elements_all )
  * This test checks xml::node::elements() const;
  */
 
-BOOST_AUTO_TEST_CASE( elements_all_const )
+TEST_CASE_METHOD( SrcdirConfig, "node/elements_all_const", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
 
@@ -225,7 +223,7 @@ BOOST_AUTO_TEST_CASE( elements_all_const )
         ostr << *i;
     }
 
-    BOOST_CHECK( is_same_as_file( ostr, "node/data/02g.out") );
+    CHECK( is_same_as_file( ostr, "node/data/02g.out") );
 }
 
 
@@ -233,14 +231,14 @@ BOOST_AUTO_TEST_CASE( elements_all_const )
  * Tests that elements() returns empty set when it should.
  */
 
-BOOST_AUTO_TEST_CASE( elements_empty )
+TEST_CASE_METHOD( SrcdirConfig, "node/elements_empty", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
     const xml::node &root = parser.get_document().get_root_node();
 
     xml::const_nodes_view view(root.elements("nonexistent"));
-    BOOST_CHECK( view.empty() );
-    BOOST_CHECK( view.begin() == view.end() );
+    CHECK( view.empty() );
+    CHECK( view.begin() == view.end() );
 }
 
 
@@ -248,14 +246,14 @@ BOOST_AUTO_TEST_CASE( elements_empty )
  * Tests that elements() returns empty set when it should.
  */
 
-BOOST_AUTO_TEST_CASE( elements_empty_all )
+TEST_CASE_METHOD( SrcdirConfig, "node/elements_empty_all", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/empty.xml").c_str());
     const xml::node &root = parser.get_document().get_root_node();
 
     xml::const_nodes_view view(root.elements());
-    BOOST_CHECK( view.empty() );
-    BOOST_CHECK( view.begin() == view.end() );
+    CHECK( view.empty() );
+    CHECK( view.begin() == view.end() );
 }
 
 
@@ -263,38 +261,38 @@ BOOST_AUTO_TEST_CASE( elements_empty_all )
  * These tests check xml::node::replace()
  */
 
-BOOST_AUTO_TEST_CASE( replace )
+TEST_CASE_METHOD( SrcdirConfig, "node/replace", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/03.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     xml::node::iterator i = root.find("to_replace", root.begin());
 
-    BOOST_REQUIRE( i != root.end() );
+    REQUIRE( i != root.end() );
 
     xml::node replacement("replace");
     replacement.push_back(xml::node("replace_child"));
     root.replace(i, replacement);
 
-    BOOST_CHECK( is_same_as_file(root, "node/data/03a.out") );
+    CHECK( is_same_as_file(root, "node/data/03a.out") );
 }
 
 
-BOOST_AUTO_TEST_CASE( replace_returned_iter )
+TEST_CASE_METHOD( SrcdirConfig, "node/replace_returned_iter", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/03.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     xml::node::iterator i = root.find("to_replace", root.begin());
 
-    BOOST_REQUIRE( i != root.end() );
+    REQUIRE( i != root.end() );
 
     xml::node replacement("replace");
     replacement.push_back(xml::node("replace_child"));
     i = root.replace(i, replacement);
 
-    BOOST_REQUIRE( i != root.end() );
-    BOOST_CHECK( is_same_as_file(*i, "node/data/03b.out") );
+    REQUIRE( i != root.end() );
+    CHECK( is_same_as_file(*i, "node/data/03b.out") );
 }
 
 
@@ -302,49 +300,49 @@ BOOST_AUTO_TEST_CASE( replace_returned_iter )
  * These tests check xml::node::erase()
  */
 
-BOOST_AUTO_TEST_CASE( erase )
+TEST_CASE_METHOD( SrcdirConfig, "node/erase", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/04.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     xml::node::iterator i = root.find("to_remove", root.begin());
 
-    BOOST_REQUIRE( i != root.end() );
+    REQUIRE( i != root.end() );
 
     root.erase(i);
 
-    BOOST_CHECK( is_same_as_file(root, "node/data/04a.out") );
+    CHECK( is_same_as_file(root, "node/data/04a.out") );
 }
 
 
-BOOST_AUTO_TEST_CASE( erase_returned_iter )
+TEST_CASE_METHOD( SrcdirConfig, "node/erase_returned_iter", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/04.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     xml::node::iterator i = root.find("to_remove", root.begin());
 
-    BOOST_REQUIRE( i != root.end() );
+    REQUIRE( i != root.end() );
 
     i = root.erase(i);
 
-    BOOST_REQUIRE( i != root.end() );
-    BOOST_CHECK( is_same_as_file(*i, "node/data/04b.out") );
+    REQUIRE( i != root.end() );
+    CHECK( is_same_as_file(*i, "node/data/04b.out") );
 }
 
 
-BOOST_AUTO_TEST_CASE( clear )
+TEST_CASE_METHOD( SrcdirConfig, "node/clear", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/04.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
 
-    BOOST_REQUIRE( root.size() > 0 );
+    REQUIRE( root.size() > 0 );
 
     root.clear();
 
-    BOOST_CHECK( root.empty() );
-    BOOST_CHECK( is_same_as_file(root, "node/data/04c.out") );
+    CHECK( root.empty() );
+    CHECK( is_same_as_file(root, "node/data/04c.out") );
 }
 
 
@@ -352,38 +350,38 @@ BOOST_AUTO_TEST_CASE( clear )
  * These tests check xml::node::insert()
  */
 
-BOOST_AUTO_TEST_CASE( insert )
+TEST_CASE_METHOD( SrcdirConfig, "node/insert", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/05.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     xml::node::iterator i = root.find("insert_before", root.begin());
 
-    BOOST_REQUIRE( i != root.end() );
+    REQUIRE( i != root.end() );
 
     root.insert(i, xml::node("inserted"));
 
-    BOOST_CHECK( is_same_as_file(root, "node/data/05a.out") );
+    CHECK( is_same_as_file(root, "node/data/05a.out") );
 }
 
 
-BOOST_AUTO_TEST_CASE( insert_returned_iter )
+TEST_CASE_METHOD( SrcdirConfig, "node/insert_returned_iter", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/05.xml").c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     xml::node::iterator i = root.find("insert_before", root.begin());
 
-    BOOST_REQUIRE( i != root.end() );
+    REQUIRE( i != root.end() );
 
     i = root.insert(i, xml::node("inserted"));
 
-    BOOST_REQUIRE( i != root.end() );
-    BOOST_CHECK( is_same_as_file(*i, "node/data/05b.out") );
+    REQUIRE( i != root.end() );
+    CHECK( is_same_as_file(*i, "node/data/05b.out") );
 }
 
 
-BOOST_AUTO_TEST_CASE( insert_in_front )
+TEST_CASE_METHOD( SrcdirConfig, "node/insert_in_front", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/05.xml").c_str());
 
@@ -391,11 +389,11 @@ BOOST_AUTO_TEST_CASE( insert_in_front )
 
     root.insert(root.begin(), xml::node("inserted"));
 
-    BOOST_CHECK( is_same_as_file(root, "node/data/05c.out") );
+    CHECK( is_same_as_file(root, "node/data/05c.out") );
 }
 
 
-BOOST_AUTO_TEST_CASE( insert_in_front_returned_iter )
+TEST_CASE_METHOD( SrcdirConfig, "node/insert_in_front_returned_iter", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/05.xml").c_str());
 
@@ -403,15 +401,15 @@ BOOST_AUTO_TEST_CASE( insert_in_front_returned_iter )
 
     xml::node::iterator i = root.insert(root.begin(), xml::node("inserted"));
 
-    BOOST_REQUIRE( i != root.end() );
-    BOOST_CHECK( is_same_as_file(*i, "node/data/05d.out") );
+    REQUIRE( i != root.end() );
+    CHECK( is_same_as_file(*i, "node/data/05d.out") );
 }
 
 
 /*
  * This test checks xml::node::move_under()
  */
-BOOST_AUTO_TEST_CASE( node_move_under )
+TEST_CASE_METHOD( SrcdirConfig, "node/node_move_under", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/02.xml").c_str());
     xml::document doc(parser.get_document());
@@ -421,11 +419,15 @@ BOOST_AUTO_TEST_CASE( node_move_under )
     xml::nodes_view::iterator i = root.elements().begin();
 
     // Check that moving the node under itself doesn't work.
-    BOOST_CHECK_THROW(i->move_under(*i->find("name")), xml::exception);
+    CHECK_THROWS_AS
+    (
+        i->move_under(*i->find("name")),
+        xml::exception&
+    );
 
     i->move_under(*root.find("unrelated_element"));
 
-    BOOST_CHECK( is_same_as_file(doc, "node/data/02_after_move.out") );
+    CHECK( is_same_as_file(doc, "node/data/02_after_move.out") );
 }
 
 
@@ -433,16 +435,16 @@ BOOST_AUTO_TEST_CASE( node_move_under )
  * This test checks xml::node::empty()
  */
 
-BOOST_AUTO_TEST_CASE( node_empty )
+TEST_CASE_METHOD( SrcdirConfig, "node/node_empty", "[node]" )
 {
     xml::node n("root");
-    BOOST_CHECK( n.empty() );
+    CHECK( n.empty() );
 
     n.push_back(xml::node("one"));
-    BOOST_CHECK( !n.empty() );
+    CHECK( !n.empty() );
 
     n.push_back(xml::node("two"));
-    BOOST_CHECK( !n.empty() );
+    CHECK( !n.empty() );
 }
 
 
@@ -450,16 +452,16 @@ BOOST_AUTO_TEST_CASE( node_empty )
  * This test checks xml::node::size()
  */
 
-BOOST_AUTO_TEST_CASE( node_size )
+TEST_CASE_METHOD( SrcdirConfig, "node/node_size", "[node]" )
 {
     xml::node n("root");
-    BOOST_CHECK_EQUAL( n.size(), 0u );
+    CHECK( n.size() == 0u );
 
     n.push_back(xml::node("one"));
-    BOOST_CHECK_EQUAL( n.size(), 1u );
+    CHECK( n.size() == 1u );
 
     n.push_back(xml::node("two"));
-    BOOST_CHECK_EQUAL( n.size(), 2u );
+    CHECK( n.size() == 2u );
 }
 
 /*
@@ -471,7 +473,7 @@ namespace
 
 void do_dump_node_types(const char *xmlfile, const char *outfile)
 {
-    xml::init::substitute_entities(false);
+    xml::init::change_flag change(&xml::init::substitute_entities, false);
 
     xml::tree_parser parser(test_file_path(xmlfile).c_str());
     xml::node &root = parser.get_document().get_root_node();
@@ -479,16 +481,12 @@ void do_dump_node_types(const char *xmlfile, const char *outfile)
     std::ostringstream ostr;
     dump_node_type(ostr, root);
 
-    BOOST_CHECK( is_same_as_file(ostr, outfile) );
-
-    // FIXME: don't rely on the default being 'true', read the current value
-    //        from xml::init
-    xml::init::substitute_entities(true);
+    CHECK( is_same_as_file(ostr, outfile) );
 }
 
 }
 
-BOOST_AUTO_TEST_CASE( dump_node_types )
+TEST_CASE_METHOD( SrcdirConfig, "node/dump_node_types", "[node]" )
 {
     do_dump_node_types("node/data/06a.xml", "node/data/06a.out");
     do_dump_node_types("node/data/06b.xml", "node/data/06b.out");
@@ -502,21 +500,17 @@ BOOST_AUTO_TEST_CASE( dump_node_types )
 
 static void do_sort_by_attr(const char *xmlfile, const char *outfile)
 {
-    xml::init::remove_whitespace(true);
+    xml::init::change_flag change(&xml::init::remove_whitespace, true);
 
     xml::tree_parser parser(test_file_path(xmlfile).c_str());
 
     xml::node &root = parser.get_document().get_root_node();
     root.sort("child", "order");
 
-    BOOST_CHECK( is_same_as_file(parser.get_document(), outfile) );
-
-    // FIXME: don't rely on the default being 'false', read the current value
-    //        from xml::init
-    xml::init::remove_whitespace(false);
+    CHECK( is_same_as_file(parser.get_document(), outfile) );
 }
 
-BOOST_AUTO_TEST_CASE( sort_by_attr )
+TEST_CASE_METHOD( SrcdirConfig, "node/sort_by_attr", "[node]" )
 {
     do_sort_by_attr("node/data/07a.xml", "node/data/07a.out");
     do_sort_by_attr("node/data/07b.xml", "node/data/07b.out");
@@ -542,9 +536,9 @@ struct node_sort_cmp : public std::binary_function<xml::node, xml::node, bool>
 
 }
 
-BOOST_AUTO_TEST_CASE( sort_with_predicate )
+TEST_CASE_METHOD( SrcdirConfig, "node/sort_with_predicate", "[node]" )
 {
-    xml::init::remove_whitespace(true);
+    xml::init::change_flag change(&xml::init::remove_whitespace, true);
 
 
     xml::tree_parser parser(test_file_path("node/data/08a.xml").c_str());
@@ -552,11 +546,7 @@ BOOST_AUTO_TEST_CASE( sort_with_predicate )
     xml::node &root = parser.get_document().get_root_node();
     root.sort(node_sort_cmp());
 
-    BOOST_CHECK( is_same_as_file(parser.get_document(), "node/data/08a.out") );
-
-    // FIXME: don't rely on the default being 'false', read the current value
-    //        from xml::init
-    xml::init::remove_whitespace(false);
+    CHECK( is_same_as_file(parser.get_document(), "node/data/08a.out") );
 }
 
 
@@ -564,12 +554,12 @@ BOOST_AUTO_TEST_CASE( sort_with_predicate )
  * This test checks xml::node::node(text)
  */
 
-BOOST_AUTO_TEST_CASE( text_node )
+TEST_CASE_METHOD( SrcdirConfig, "node/text_node", "[node]" )
 {
     xml::node root("root");
     xml::node n(xml::node::text("some text"));
     root.push_back(n);
-    BOOST_CHECK( is_same_as_file(root, "node/data/14.out") );
+    CHECK( is_same_as_file(root, "node/data/14.out") );
 }
 
 
@@ -577,10 +567,10 @@ BOOST_AUTO_TEST_CASE( text_node )
  * This test checks xml::node::node(cdata)
  */
 
-BOOST_AUTO_TEST_CASE( cdata_node )
+TEST_CASE_METHOD( SrcdirConfig, "node/cdata_node", "[node]" )
 {
     xml::node n(xml::node::cdata("This is a CDATA section"));
-    BOOST_CHECK( is_same_as_file(n, "node/data/09.out") );
+    CHECK( is_same_as_file(n, "node/data/09.out") );
 }
 
 
@@ -588,10 +578,10 @@ BOOST_AUTO_TEST_CASE( cdata_node )
  * This test checks xml::node::node(comment)
  */
 
-BOOST_AUTO_TEST_CASE( comment_node )
+TEST_CASE_METHOD( SrcdirConfig, "node/comment_node", "[node]" )
 {
     xml::node n(xml::node::comment("This is an XML comment"));
-    BOOST_CHECK( is_same_as_file(n, "node/data/10.out") );
+    CHECK( is_same_as_file(n, "node/data/10.out") );
 }
 
 
@@ -599,10 +589,10 @@ BOOST_AUTO_TEST_CASE( comment_node )
  * This test checks xml::node::node(pi)
  */
 
-BOOST_AUTO_TEST_CASE( processing_instruction )
+TEST_CASE_METHOD( SrcdirConfig, "node/processing_instruction", "[node]" )
 {
     xml::node n(xml::node::pi("xslt", "stylesheet=\"test.xsl\""));
-    BOOST_CHECK( is_same_as_file(n, "node/data/11.out") );
+    CHECK( is_same_as_file(n, "node/data/11.out") );
 }
 
 
@@ -610,76 +600,76 @@ BOOST_AUTO_TEST_CASE( processing_instruction )
  * Test correct (expected) handling of text escaping.
  */
 
-BOOST_AUTO_TEST_CASE( text_substitute_entities )
+TEST_CASE_METHOD( SrcdirConfig, "node/text_substitute_entities", "[node]" )
 {
     xml::tree_parser parser(test_file_path("node/data/special_chars.xml").c_str());
     xml::node &root = parser.get_document().get_root_node();
 
     const std::string content = root.get_content();
 
-    BOOST_CHECK_EQUAL( content, "Marlow & Sons" );
+    CHECK_THAT( content, Catch::Matchers::Equals("Marlow & Sons") );
 }
 
 
-BOOST_AUTO_TEST_CASE( escape_node_with_content )
+TEST_CASE_METHOD( SrcdirConfig, "node/escape_node_with_content", "[node]" )
 {
     xml::node n("root", "Marlow & Sons");
 
-    BOOST_CHECK_EQUAL( n.get_content(), "Marlow & Sons" );
-    BOOST_CHECK( is_same_as_file(n, "node/data/special_chars.xml") );
+    CHECK_THAT( n.get_content(), Catch::Matchers::Equals("Marlow & Sons") );
+    CHECK( is_same_as_file(n, "node/data/special_chars.xml") );
 }
 
 
-BOOST_AUTO_TEST_CASE( escape_text_node )
+TEST_CASE_METHOD( SrcdirConfig, "node/escape_text_node", "[node]" )
 {
     xml::node n("root");
     n.push_back(xml::node(xml::node::text("Marlow & Sons")));
 
-    BOOST_CHECK_EQUAL( n.get_content(), "Marlow & Sons" );
-    BOOST_CHECK( is_same_as_file(n, "node/data/special_chars.xml") );
+    CHECK_THAT( n.get_content(), Catch::Matchers::Equals("Marlow & Sons") );
+    CHECK( is_same_as_file(n, "node/data/special_chars.xml") );
 }
 
 
-BOOST_AUTO_TEST_CASE( escape_set_content )
+TEST_CASE_METHOD( SrcdirConfig, "node/escape_set_content", "[node]" )
 {
     xml::node n("root");
     // Note that set_content() takes CDATA content as argument, so "&"
     // has to be written as "&amp;".
     n.set_content("Marlow &amp; Sons");
 
-    BOOST_CHECK_EQUAL( n.get_content(), "Marlow & Sons" );
-    BOOST_CHECK( is_same_as_file(n, "node/data/special_chars.xml") );
+    CHECK_THAT( n.get_content(), Catch::Matchers::Equals("Marlow & Sons") );
+    CHECK( is_same_as_file(n, "node/data/special_chars.xml") );
 }
 
 
-BOOST_AUTO_TEST_CASE( escape_set_text_content )
+TEST_CASE_METHOD( SrcdirConfig, "node/escape_set_text_content", "[node]" )
 {
     xml::node n("root");
     n.set_text_content("Marlow & Sons");
 
-    BOOST_CHECK_EQUAL( n.get_content(), "Marlow & Sons" );
-    BOOST_CHECK( is_same_as_file(n, "node/data/special_chars.xml") );
+    CHECK_THAT( n.get_content(), Catch::Matchers::Equals("Marlow & Sons") );
+    CHECK( is_same_as_file(n, "node/data/special_chars.xml") );
 }
 
 
-BOOST_AUTO_TEST_CASE( compare_node_iterators )
+TEST_CASE_METHOD( SrcdirConfig, "node/compare_node_iterators", "[node]" )
 {
     xml::node n("root");
     xml::node::iterator i = n.begin();
     xml::node::const_iterator ci = n.begin();
 
-    BOOST_CHECK( i == i );
-    BOOST_CHECK( !(i != i) );
-    BOOST_CHECK( ci == ci );
-    BOOST_CHECK( !(ci != ci) );
-    BOOST_CHECK( i == ci );
-    BOOST_CHECK( !(i != ci) );
-    BOOST_CHECK( ci == i );
-    BOOST_CHECK( !(ci != i) );
+    CHECK( i == i );
+    CHECK( !(i != i) );
+    CHECK( ci == ci );
+    CHECK( !(ci != ci) );
+    CHECK( i == ci );
+    CHECK( !(i != ci) );
+    CHECK( ci == i );
+    CHECK( !(ci != i) );
 }
 
 
-BOOST_AUTO_TEST_CASE( compare_nodes_view_iterators )
+TEST_CASE_METHOD( SrcdirConfig, "node/compare_nodes_view_iterators", "[node]" )
 {
     xml::node n("root");
     xml::nodes_view view(n.elements("foo"));
@@ -691,61 +681,90 @@ BOOST_AUTO_TEST_CASE( compare_nodes_view_iterators )
     xml::const_nodes_view::iterator i2 = cview.begin();
     xml::const_nodes_view::const_iterator ci2 = cview.begin();
 
-    BOOST_CHECK( i == i );
-    BOOST_CHECK( !(i != i) );
-    BOOST_CHECK( ci == ci );
-    BOOST_CHECK( !(ci != ci) );
-    BOOST_CHECK( i == ci );
-    BOOST_CHECK( !(i != ci) );
-    BOOST_CHECK( ci == i );
-    BOOST_CHECK( !(ci != i) );
+    CHECK( i == i );
+    CHECK( !(i != i) );
+    CHECK( ci == ci );
+    CHECK( !(ci != ci) );
+    CHECK( i == ci );
+    CHECK( !(i != ci) );
+    CHECK( ci == i );
+    CHECK( !(ci != i) );
 
-    BOOST_CHECK( i2 == i2 );
-    BOOST_CHECK( !(i2 != i2) );
-    BOOST_CHECK( ci2 == ci2 );
-    BOOST_CHECK( !(ci2 != ci2) );
-    BOOST_CHECK( i2 == ci2 );
-    BOOST_CHECK( !(i2 != ci2) );
-    BOOST_CHECK( ci2 == i2 );
-    BOOST_CHECK( !(ci2 != i2) );
+    CHECK( i2 == i2 );
+    CHECK( !(i2 != i2) );
+    CHECK( ci2 == ci2 );
+    CHECK( !(ci2 != ci2) );
+    CHECK( i2 == ci2 );
+    CHECK( !(i2 != ci2) );
+    CHECK( ci2 == i2 );
+    CHECK( !(ci2 != i2) );
 
-    BOOST_CHECK( i2 == i );
-    BOOST_CHECK( !(i2 != i) );
-    BOOST_CHECK( ci2 == ci );
-    BOOST_CHECK( !(ci2 != ci) );
-    BOOST_CHECK( i2 == ci );
-    BOOST_CHECK( !(i2 != ci) );
-    BOOST_CHECK( ci2 == i );
-    BOOST_CHECK( !(ci2 != i) );
+    CHECK( i2 == i );
+    CHECK( !(i2 != i) );
+    CHECK( ci2 == ci );
+    CHECK( !(ci2 != ci) );
+    CHECK( i2 == ci );
+    CHECK( !(i2 != ci) );
+    CHECK( ci2 == i );
+    CHECK( !(ci2 != i) );
 
-    BOOST_CHECK( i == i2 );
-    BOOST_CHECK( !(i != i2) );
-    BOOST_CHECK( ci == ci2 );
-    BOOST_CHECK( !(ci != ci2) );
-    BOOST_CHECK( i == ci2 );
-    BOOST_CHECK( !(i != ci2) );
-    BOOST_CHECK( ci == i2 );
-    BOOST_CHECK( !(ci != i2) );
+    CHECK( i == i2 );
+    CHECK( !(i != i2) );
+    CHECK( ci == ci2 );
+    CHECK( !(ci != ci2) );
+    CHECK( i == ci2 );
+    CHECK( !(i != ci2) );
+    CHECK( ci == i2 );
+    CHECK( !(ci != i2) );
 }
 
-
-BOOST_AUTO_TEST_CASE( get_namespace )
+// Test fixture providing "doc" preloaded with the contents of namespace.xml.
+class NamespaceTest : private SrcdirConfig
 {
-    xml::tree_parser parser(test_file_path("node/data/namespace.xml").c_str());
+public:
+    NamespaceTest()
+        : parser(test_file_path("node/data/namespace.xml").c_str()),
+          doc(parser.get_document())
+    {
+    }
 
-    BOOST_CHECK_EQUAL( parser.get_document().get_root_node().get_namespace(),
-                       "http://pmade.org/namespace/test" );
+protected:
+    xml::tree_parser parser;
+    xml::document doc;
+};
+
+TEST_CASE_METHOD( NamespaceTest, "node/get_namespace", "[node][ns]" )
+{
+    CHECK_THAT
+    (
+        doc.get_root_node().get_namespace(),
+        Catch::Matchers::Equals("http://pmade.org/namespace/test")
+    );
 }
 
-BOOST_AUTO_TEST_CASE( set_namespace )
+TEST_CASE_METHOD( NamespaceTest, "node/set_namespace", "[node][ns]" )
 {
-    xml::tree_parser parser(test_file_path("node/data/namespace.xml").c_str());
-    xml::document doc(parser.get_document());
-
     doc.get_root_node().set_namespace("http://pmade.org/namespace/newOne");
 
-    BOOST_CHECK( is_same_as_file(doc, "node/data/namespace.out") );
+    CHECK( is_same_as_file(doc, "node/data/namespace.out") );
 }
 
+TEST_CASE_METHOD( NamespaceTest, "node/copy_ns", "[node][ns]" )
+{
+    xml::node& root = doc.get_root_node();
+    xml::node::iterator foo = root.find("foo");
+    REQUIRE( foo != root.end() );
 
-BOOST_AUTO_TEST_SUITE_END()
+    xml::node child_with_same_ns("child_with_same_ns");
+    child_with_same_ns.set_namespace("http://pmade.org/namespace/test");
+    foo->insert(child_with_same_ns);
+
+    xml::node child_with_diff_ns("child_with_diff_ns");
+    child_with_diff_ns.set_namespace("http://pmade.org/namespace/different");
+    foo->insert(child_with_diff_ns);
+
+    xml::node::iterator bar = root.insert(xml::node("bar"));
+    bar->insert(*foo);
+
+    CHECK( is_same_as_file(doc, "node/data/copy_ns.out") );
+}
